.. highlight:: bash

.. _forking:

======================================================
Making your own copy (fork) of Matplotlib
======================================================

You need to do this only once.  The instructions here are very similar
to the instructions at https://help.github.com/forking/ |emdash| please see
that page for more detail.  We're repeating some of it here just to give the
specifics for the `Matplotlib`_ project, and to suggest some default names.

Set up and configure a github account
=====================================

If you don't have a github account, go to the github page, and make one.

You then need to configure your account to allow write access |emdash| see
the ``Generating SSH keys`` help on `github help`_.

Create your own forked copy of `Matplotlib`_
======================================================

#. Log into your github account.
#. Go to the `Matplotlib`_ github home at `Matplotlib github`_.
#. Click on the *fork* button:

   .. image:: forking_button.png

   Now, after a short pause, you should find yourself at the home page for
   your own forked copy of `Matplotlib`_.

.. include:: links.inc
